@@ -4,7 +4,7 @@ print.ordforpred <-
   function(x, ...) {
     
     cat("\n")
-    cat(paste("Predicted values of ", length(x$ypred), " observations.", sep=""), "\n")
+    cat(paste("Predicted values of ", length(x$ypred), " observation(s).", sep=""), "\n")
     
     cat("\n")
     cat("Classes of ordinal target variable:", "\n")
